pub struct WasmtimeStoreData {
pub hostcall_val_storage: Vec<wasmtime_val_t>,
pub wasm_val_storage: Vec<Val>,
pub store_limits: StoreLimits,
/* private fields */
}Fields
hostcall_val_storage: Vec<wasmtime_val_t>Temporary storage for usage during a wasm->host call to store values in a slice we pass to the C API.
wasm_val_storage: Vec<Val>Temporary storage for usage during host->wasm calls, same as above but for a different direction.
store_limits: StoreLimitsLimits for the store.