wasmtime_val_t

Struct wasmtime_val_t 

#[repr(C)]
pub struct wasmtime_val_t { pub kind: wasmtime_valkind_t, pub of: wasmtime_val_union, }

Fields

kind: wasmtime_valkind_tof: wasmtime_val_union

Implementations

Source

impl wasmtime_val_t

pub fn from_val(cx: impl AsContextMut, val: Val) -> wasmtime_val_t

Creates a new wasmtime_val_t from a wasmtime::Val (non-gc version).

When gc feature is disabled, this does not require a RootScope.

pub fn from_val_unscoped(cx: impl AsContextMut, val: Val) -> wasmtime_val_t

Equivalent of wasmtime_val_t::from_val except that a RootScope is not required.

This method should only be used when a RootScope is known to be elsewhere on the stack. For example this is used when we call back out to the embedder. In such a situation we know we previously entered with some other call so the root scope is on the stack there.

pub unsafe fn to_val(&self, cx: impl AsContextMut) -> Val

Convert this wasmtime_val_t into a wasmtime::Val (non-gc version).

When gc feature is disabled, this does not require a RootScope.

pub unsafe fn to_val_unscoped(&self, cx: impl AsContextMut) -> Val

Equivalent of to_val except doesn’t require a RootScope.

See notes on wasmtime_val_t::from_val_unscoped for notes on when to use this.